@@ -3,7 +3,7 @@ import json
 import time
 import os
 
-from resources import getResourceName
+import quantum_lab.resources
 
 class quantum_lab():
 
@@ -27,9 +27,9 @@ class quantum_lab():
 
 
     def getDirpath(self, dirPath):
-        dirList = os.listdir(f"/home/jovyan/{dirPath}")
+        dirList = os.listdir(f"/home/jovyan/")
         for dirName in dirList:
-            if self.volumeName == dirName:
+            if dirPath == dirName:
                 return f"/home/jovyan/{dirName}"
         return 0
 
